==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kendra/kotlin/outputs/GetIndexDocumentMetadataConfigurationUpdateSearch.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kendra.kotlin.outputs

import kotlin.Boolean
import kotlin.Suppress

/**
 *
 * @property displayable Determines whether the field is returned in the query response. The default is `true`.
 * @property facetable Whether the field can be used to create search facets, a count of results for each value in the field. The default is `false`.
 * @property searchable Determines whether the field is used in the search. If the Searchable field is true, you can use relevance tuning to manually tune how Amazon Kendra weights the field in the search. The default is `true` for `string` fields and `false` for `number` and `date` fields.
 * @property sortable Determines whether the field can be used to sort the results of a query. If you specify sorting on a field that does not have Sortable set to true, Amazon Kendra returns an exception. The default is `false`.
 */
public data class GetIndexDocumentMetadataConfigurationUpdateSearch(
    public val displayable: Boolean,
    public val facetable: Boolean,
    public val searchable: Boolean,
    public val sortable: Boolean,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.kendra.outputs.GetIndexDocumentMetadataConfigurationUpdateSearch):
            GetIndexDocumentMetadataConfigurationUpdateSearch =
            GetIndexDocumentMetadataConfigurationUpdateSearch(
                displayable = javaType.displayable(),
                facetable = javaType.facetable(),
                searchable = javaType.searchable(),
                sortable = javaType.sortable(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kendra/kotlin/outputs/GetIndexDocumentMetadataConfigurationUpdateSearch.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kendra.kotlin.outputs

import kotlin.Boolean
import kotlin.Suppress

/**
 *
 * @property displayable Determines whether the field is returned in the query response. The default is `true`.
 * @property facetable Whether the field can be used to create search facets, a count of results for each value in the field. The default is `false`.
 * @property searchable Determines whether the field is used in the search. If the Searchable field is true, you can use relevance tuning to manually tune how Amazon Kendra weights the field in the search. The default is `true` for `string` fields and `false` for `number` and `date` fields.
 * @property sortable Determines whether the field can be used to sort the results of a query. If you specify sorting on a field that does not have Sortable set to true, Amazon Kendra returns an exception. The default is `false`.
 */
public data class GetIndexDocumentMetadataConfigurationUpdateSearch(
    public val displayable: Boolean,
    public val facetable: Boolean,
    public val searchable: Boolean,
    public val sortable: Boolean,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.kendra.outputs.GetIndexDocumentMetadataConfigurationUpdateSearch): GetIndexDocumentMetadataConfigurationUpdateSearch =
            GetIndexDocumentMetadataConfigurationUpdateSearch(
                displayable = javaType.displayable(),
                facetable = javaType.facetable(),
                searchable = javaType.searchable(),
                sortable = javaType.sortable(),
            )
    }
}
